# ESP32_stand-alone_climate_station.py
# Baro: BMP180, Thermo: 2x DS18x20, Hygro: DHT11, 
# Display: SSD1306

from machine import Pin, I2C
import ssd1306
import dht 
from time import sleep
from bmp180 import BMP180
import onewire
import ds18x20

# i2c pin assignmet
i2c = I2C(-1, scl=Pin(22), sda=Pin(21))

# temp initialization DS18x20
ow = onewire.OneWire(Pin(25))   #Init wire
ow.scan()
ds=ds18x20.DS18X20(ow)          #create ds18x20 object

# baro initialization BMP180
bmp = BMP180(i2c)
bmp.oversample = 2
bmp.sealevel = 101325

# hygro initialization DHT11
sensor = dht.DHT11(Pin(14))
DHT_cal = 1

# OLED dimensions and initialization SSD1306
oled_width = 128
oled_height = 64
oled = ssd1306.SSD1306_I2C(oled_width, oled_height, i2c)
d1 = 60 # column distance 1
d2 = 90 # column distance 1
h1 = 9  # line hight
  
while True:
  try:
    oled.fill(0)
    oled.text('Climate Station', 0, 0)

    # DHT11: Temp & Humiture
    sensor.measure()
    temp = sensor.temperature()+DHT_cal
    hum = sensor.humidity()
    print('Temp1: %3.1f C' %temp)
    print('Humi : %3.1f %%' %hum)
    
    temperature_string = str(int(10*temp)/10)
    humidity_string = str(int(10*hum)/10)
    
    oled.text('Temp1:', 0 ,h1)
    oled.text(temperature_string, d1 ,h1)
    oled.text(' C', d2 ,h1)

    oled.text('Humi :', 0 , 2*h1)
    oled.text(humidity_string, d1 ,2*h1)
    oled.text(' %', d2 ,2*h1)
    
    # BMP180: Temp & pressure
    temp = bmp.temperature
    pres = int(bmp.pressure/100)
       
    print('Temp2: %3.1f C' %temp)
    print('Baro : %3.0f hPa' %pres)
    
    temperature_string = str(int(10*temp)/10)
    pressure_string = str(pres)
    
    oled.text('Temp2:', 0 ,3*h1)
    oled.text(temperature_string, d1 ,3*h1)
    oled.text(' C', d2 ,3*h1)

    oled.text('Baro :', 0 ,4*h1)
    oled.text(pressure_string, d1 ,4*h1)
    oled.text(' hPa', d2 ,4*h1)

    # DS18x20 2xTemp
    roms=ds.scan()                

    ds.convert_temp()             
    n = 1
    for rom in roms:
      print('Temp : %3.1f C' %ds.read_temp(rom))    
      temperature_string = str(int(10*ds.read_temp(rom))/10)
      oled.text('Temp', 0 ,(4+n)*h1) 
      oled.text(str(n+2), 32 ,(4+n)*h1) 
      oled.text(':', 40 ,(4+n)*h1) 
      oled.text(temperature_string, d1 ,(4+n)*h1)
      oled.text(' C', d2 ,(4+n)*h1)
      n = n + 1
     
    print()
    oled.show()
    sleep(1)
    
  except OSError as e:
    print('Failed to read sensor')
    oled.fill(0)
    oled.text('Sensor error', 0, 0)
    oled.show()